@@ -3,7 +3,7 @@ iris$Sepal.Width_sq <- iris$Sepal.Width^2
 fit <- glm(I(Species)=="virginica" ~ ., data=iris)
 
 model.require <- function() {
-  # require("randomForest")
+
 }
 
 model.transform <- function(df) {
@@ -13,9 +13,12 @@ model.transform <- function(df) {
 model.predict <- function(df) {
   data.frame("prediction"=predict(fit, df, type="response"))
 }
-yhat.config <- c(username = "greg", apikey = "fCVZiLJhS95cnxOrsp5e2VSkk0GfypZqeRCntTD1nHA")
-yhat.deploy("irisModel")
+yhat.config <- c(username = "your username", apikey = "your apikey")
+
+deployment <- yhat.deploy("irisModel")
+
+active_version <- deployment[1,]$version
 
 lapply(1:nrow(iris), function(i) {
-  print(yhat.predict("irisModel", 5, iris[i,]))
+  print(yhat.predict("irisModel", active_version, iris[i,]))
 })
\ No newline at end of file
