@@ -17,15 +17,17 @@ model.transform <- function(df) {
 model.predict <- function(df) {
   data.frame("prediction"=predict(fit, df, type="response"))
 }
-yhat.config <- c(username = "greg", apikey = "fCVZiLJhS95cnxOrsp5e2VSkk0GfypZqeRCntTD1nHA")
-yhat.deploy("irisModel")
+yhat.config <- c(username = "your username", apikey = "your apikey")
+(deployment <- yhat.deploy("irisModel"))
+
+active_version <- deployment[1,]$version
 
 predict(fit, iris[1,])
-yhat.predict("irisModel", 6, iris[1,])
+yhat.predict("irisModel", active_version, iris[1,])
 
 results <- ldply(1:nrow(iris), function(i) {
   data.frame(idx=i,
-             yhat=yhat.predict("irisModel", 6, iris[i,])$prediction,
+             yhat=yhat.predict("irisModel", active_version, iris[i,])$prediction,
              local=predict(fit, iris[i,]))
 })
 
